==> galil_gclib_1_33_4.zip: doc/html/gclib__errors_8h.js <==
var gclib__errors_8h =
[
    [ "G_ARRAY_NOT_DIMENSIONED", "group__cpp__api.html#ga6d4d3803dc3a4c120f4ca38eace94b84", null ],
    [ "G_ARRAY_NOT_DIMENSIONED_S", "group__cpp__api.html#gaa8b0efb39ab47d4593bd83c0bb49048b", null ],
    [ "G_BAD_ADDRESS", "group__cpp__api.html#ga8ffef0581b8be5ca8a4ff80ef7b5f1fe", null ],
    [ "G_BAD_ADDRESS_S", "group__cpp__api.html#ga179219b2bbe8217d95ff98a488860617", null ],
    [ "G_BAD_FILE", "group__cpp__api.html#gabade08412846aeb1e4c7c8d1a13c6ab4", null ],
    [ "G_BAD_FILE_S", "group__cpp__api.html#ga2c9118b3829a2b0cac8ec8643c58de36", null ],
    [ "G_BAD_FIRMWARE_LOAD", "group__cpp__api.html#ga30e823d29e5c6fdae16f65917ecfffaf", null ],
    [ "G_BAD_FIRMWARE_LOAD_S", "group__cpp__api.html#gab5f8c8f51d221460b37b1f960598efce", null ],
    [ "G_BAD_FULL_MEMORY", "group__cpp__api.html#ga5d3f1002943a2d805fcd0c092fbf6166", null ],
    [ "G_BAD_FULL_MEMORY_S", "group__cpp__api.html#ga0bbf4da887d0d4533d47507216d81132", null ],
    [ "G_BAD_LOST_DATA", "group__cpp__api.html#gac333dced7051170eb12570c10f4a7565", null ],
    [ "G_BAD_LOST_DATA_S", "group__cpp__api.html#ga80c904fe7dde656ce0248d87610bd925", null ],
    [ "G_BAD_RESPONSE_QUESTION_MARK", "group__cpp__api.html#ga00944959e3f761b1b5580df6f2b6571d", null ],
    [ "G_BAD_RESPONSE_QUESTION_MARK_S", "group__cpp__api.html#ga5c3ad144d2f70755b988fef7dd58c556", null ],
    [ "G_BAD_VALUE_RANGE", "group__cpp__api.html#ga17a4a5dd28cf5d8bf9532731935e553d", null ],
    [ "G_BAD_VALUE_RANGE_S", "group__cpp__api.html#ga900d8d9e8c1b4d8c3a334a007f62591f", null ],
    [ "G_COMMAND_CALLED_WITH_ILLEGAL_COMMAND", "group__cpp__api.html#ga10e7f9156edeb788b9af34b7e17875ce", null ],
    [ "G_COMMAND_CALLED_WITH_ILLEGAL_COMMAND_S", "group__cpp__api.html#ga32aeed918c5861ad89e323b713d6fc5e", null ],
    [ "G_CONNECTION_NOT_ESTABLISHED", "group__cpp__api.html#gaa4fa277efa159966968fd135993025bc", null ],
    [ "G_CONNECTION_NOT_ESTABLISHED_S", "group__cpp__api.html#ga20e02dca7623bee459cb5998eaf5a4ef", null ],
    [ "G_DATA_RECORD_ERROR", "group__cpp__api.html#ga061a031939b3693b50808d560a8cce17", null ],
    [ "G_DATA_RECORD_ERROR_S", "group__cpp__api.html#ga10129cb8de42c73c8012e4d2a6d9c23c", null ],
    [ "G_FIRMWARE_LOAD_NOT_SUPPORTED", "group__cpp__api.html#ga876879e3ebd088ef3ef8d5cc7bcac1c6", null ],
    [ "G_FIRMWARE_LOAD_NOT_SUPPORTED_S", "group__cpp__api.html#ga25c58a328d3a8f5f3f652a1d4a253554", null ],
    [ "G_GCAPS_OPEN_ERROR", "group__cpp__api.html#ga43fa8c421c79899a76515c969c58de4c", null ],
    [ "G_GCAPS_OPEN_ERROR_S", "group__cpp__api.html#ga2fc8c352fc52c5b7ba2b99b166d28108", null ],
    [ "G_GCAPS_SUBSCRIPTION_ERROR", "group__cpp__api.html#ga96df27bfdd24c6c5be36125ad937a239", null ],
    [ "G_GCAPS_SUBSCRIPTION_ERROR_S", "group__cpp__api.html#ga1e37e56eb8544a440eaab53cb6e08cfe", null ],
    [ "G_GCLIB_ERROR", "group__cpp__api.html#ga4207cd5c13df341537b3c15715b2fc02", null ],
    [ "G_GCLIB_ERROR_S", "group__cpp__api.html#gaaef746de87c99bc1ec4b31d166c0a22d", null ],
    [ "G_GCLIB_NON_BLOCKING_READ_EMPTY", "group__cpp__api.html#gad7e1bfb854c9fa249bb2e63b82a557fc", null ],
    [ "G_GCLIB_NON_BLOCKING_READ_EMPTY_S", "group__cpp__api.html#gaa77d1367a8507c670b4c47b05d83dfb4", null ],
    [ "G_GCLIB_POLLING_FAILED", "group__cpp__api.html#gabbca3ab5dbb590881f7f2cdeec9b30e2", null ],
    [ "G_GCLIB_POLLING_FAILED_S", "group__cpp__api.html#ga5acc07a88ba524e74c75741d3166bd58", null ],
    [ "G_GCLIB_UTILITY_ERROR", "group__cpp__api.html#gab0a2ef6554c69f0089d11f9930c2ace1", null ],
    [ "G_GCLIB_UTILITY_ERROR_S", "group__cpp__api.html#ga8dde41f95622092e369da423ad2e44dd", null ],
    [ "G_GCLIB_UTILITY_IP_TAKEN", "group__cpp__api.html#gaecd7f62e0972ac4be677ba68365d11e5", null ],
    [ "G_GCLIB_UTILITY_IP_TAKEN_S", "group__cpp__api.html#ga31b428919468e475ba05836d00de1faf", null ],
    [ "G_ILLEGAL_DATA_IN_PROGRAM", "group__cpp__api.html#gafc7d5bb6ad219829ca6533ff87d96056", null ],
    [ "G_ILLEGAL_DATA_IN_PROGRAM_S", "group__cpp__api.html#gaf7e6b95de220f39f61f8a35abf303fa6", null ],
    [ "G_INVALID_PREPROCESSOR_OPTIONS", "group__cpp__api.html#ga4bcc4cc8c4880acf82319cbdec827d47", null ],
    [ "G_INVALID_PREPROCESSOR_OPTIONS_S", "group__cpp__api.html#ga7ee237937c4335a6b43ed94319115035", null ],
    [ "G_NO_ERROR", "group__cpp__api.html#ga46e5adb966864971f3d6b4a1decf5954", null ],
    [ "G_NO_ERROR_S", "group__cpp__api.html#ga7d6dd86ae2b6307adf6d05f108269cf8", null ],
    [ "G_OPEN_ERROR", "group__cpp__api.html#ga44e34d4559d3d09cd550c45e12483108", null ],
    [ "G_OPEN_ERROR_S", "group__cpp__api.html#gacc70913c5d86130391fab2a2ba5155bb", null ],
    [ "G_READ_ERROR", "group__cpp__api.html#gabce68d1f465996cbaaac153b9940d621", null ],
    [ "G_READ_ERROR_S", "group__cpp__api.html#ga20a339f9fa688b67c47706a3b057b9d3", null ],
    [ "G_TIMEOUT", "group__cpp__api.html#gaef68529afafeb30e5f60c9d698408bf0", null ],
    [ "G_TIMEOUT_S", "group__cpp__api.html#ga9651f9c31449c92cc0edd295136d4ebd", null ],
    [ "G_UNABLE_TO_COMPRESS_PROGRAM_TO_FIT", "group__cpp__api.html#gae1864af8c72153a6f00432fac75dc5b4", null ],
    [ "G_UNABLE_TO_COMPRESS_PROGRAM_TO_FIT_S", "group__cpp__api.html#ga0349cd85016a55aefcf1281c49e6b119", null ],
    [ "G_UNSUPPORTED_FUNCTION", "group__cpp__api.html#gab6ff4f5067dbe90c1e369ecf878848fd", null ],
    [ "G_UNSUPPORTED_FUNCTION_S", "group__cpp__api.html#ga89cf3cf24b91c0eb79a794a2445a327c", null ],
    [ "G_WRITE_ERROR", "group__cpp__api.html#ga036c9dd80229ef8a3343281e5d64e026", null ],
    [ "G_WRITE_ERROR_S", "group__cpp__api.html#gaf35a97da9caf2b7965f9c1eb7fc370b5", null ]
];

==> galil_gclib_2_0_7.zip: doc/html/gclib__errors_8h.js <==
var gclib__errors_8h =
[
    [ "G_ALREADY_OPEN", "group__cpp__api.html#ga3a9e326973f73738b2f031f3c6b4187c", null ],
    [ "G_ALREADY_OPEN_S", "group__cpp__api.html#gabc56d879caf7a3dea2deaf5e95a94ae0", null ],
    [ "G_ARRAY_NOT_DIMENSIONED", "group__cpp__api.html#ga6d4d3803dc3a4c120f4ca38eace94b84", null ],
    [ "G_ARRAY_NOT_DIMENSIONED_S", "group__cpp__api.html#gaa8b0efb39ab47d4593bd83c0bb49048b", null ],
    [ "G_BAD_ADDRESS", "group__cpp__api.html#ga8ffef0581b8be5ca8a4ff80ef7b5f1fe", null ],
    [ "G_BAD_ADDRESS_S", "group__cpp__api.html#ga179219b2bbe8217d95ff98a488860617", null ],
    [ "G_BAD_FILE", "group__cpp__api.html#gabade08412846aeb1e4c7c8d1a13c6ab4", null ],
    [ "G_BAD_FILE_S", "group__cpp__api.html#ga2c9118b3829a2b0cac8ec8643c58de36", null ],
    [ "G_BAD_FIRMWARE_LOAD", "group__cpp__api.html#ga30e823d29e5c6fdae16f65917ecfffaf", null ],
    [ "G_BAD_FIRMWARE_LOAD_S", "group__cpp__api.html#gab5f8c8f51d221460b37b1f960598efce", null ],
    [ "G_BAD_FULL_MEMORY", "group__cpp__api.html#ga5d3f1002943a2d805fcd0c092fbf6166", null ],
    [ "G_BAD_FULL_MEMORY_S", "group__cpp__api.html#ga0bbf4da887d0d4533d47507216d81132", null ],
    [ "G_BAD_LOST_DATA", "group__cpp__api.html#gac333dced7051170eb12570c10f4a7565", null ],
    [ "G_BAD_LOST_DATA_S", "group__cpp__api.html#ga80c904fe7dde656ce0248d87610bd925", null ],
    [ "G_BAD_RESPONSE_QUESTION_MARK", "group__cpp__api.html#ga00944959e3f761b1b5580df6f2b6571d", null ],
    [ "G_BAD_RESPONSE_QUESTION_MARK_S", "group__cpp__api.html#ga5c3ad144d2f70755b988fef7dd58c556", null ],
    [ "G_BAD_VALUE_RANGE", "group__cpp__api.html#ga17a4a5dd28cf5d8bf9532731935e553d", null ],
    [ "G_BAD_VALUE_RANGE_S", "group__cpp__api.html#ga900d8d9e8c1b4d8c3a334a007f62591f", null ],
    [ "G_COMMAND_CALLED_WITH_ILLEGAL_COMMAND", "group__cpp__api.html#ga10e7f9156edeb788b9af34b7e17875ce", null ],
    [ "G_COMMAND_CALLED_WITH_ILLEGAL_COMMAND_S", "group__cpp__api.html#ga32aeed918c5861ad89e323b713d6fc5e", null ],
    [ "G_CONNECTION_NOT_ESTABLISHED", "group__cpp__api.html#gaa4fa277efa159966968fd135993025bc", null ],
    [ "G_CONNECTION_NOT_ESTABLISHED_S", "group__cpp__api.html#ga20e02dca7623bee459cb5998eaf5a4ef", null ],
    [ "G_DATA_RECORD_ERROR", "group__cpp__api.html#ga061a031939b3693b50808d560a8cce17", null ],
    [ "G_DATA_RECORD_ERROR_S", "group__cpp__api.html#ga10129cb8de42c73c8012e4d2a6d9c23c", null ],
    [ "G_FIRMWARE_LOAD_NOT_SUPPORTED", "group__cpp__api.html#ga876879e3ebd088ef3ef8d5cc7bcac1c6", null ],
    [ "G_FIRMWARE_LOAD_NOT_SUPPORTED_S", "group__cpp__api.html#ga25c58a328d3a8f5f3f652a1d4a253554", null ],
    [ "G_GCAPS_OPEN_ERROR", "group__cpp__api.html#ga43fa8c421c79899a76515c969c58de4c", null ],
    [ "G_GCAPS_OPEN_ERROR_S", "group__cpp__api.html#ga2fc8c352fc52c5b7ba2b99b166d28108", null ],
    [ "G_GCAPS_SUBSCRIPTION_ERROR", "group__cpp__api.html#ga96df27bfdd24c6c5be36125ad937a239", null ],
    [ "G_GCAPS_SUBSCRIPTION_ERROR_S", "group__cpp__api.html#ga1e37e56eb8544a440eaab53cb6e08cfe", null ],
    [ "G_GCLIB_ERROR", "group__cpp__api.html#ga4207cd5c13df341537b3c15715b2fc02", null ],
    [ "G_GCLIB_ERROR_S", "group__cpp__api.html#gaaef746de87c99bc1ec4b31d166c0a22d", null ],
    [ "G_GCLIB_NON_BLOCKING_READ_EMPTY", "group__cpp__api.html#gad7e1bfb854c9fa249bb2e63b82a557fc", null ],
    [ "G_GCLIB_NON_BLOCKING_READ_EMPTY_S", "group__cpp__api.html#gaa77d1367a8507c670b4c47b05d83dfb4", null ],
    [ "G_GCLIB_POLLING_FAILED", "group__cpp__api.html#gabbca3ab5dbb590881f7f2cdeec9b30e2", null ],
    [ "G_GCLIB_POLLING_FAILED_S", "group__cpp__api.html#ga5acc07a88ba524e74c75741d3166bd58", null ],
    [ "G_GCLIB_UTILITY_ERROR", "group__cpp__api.html#gab0a2ef6554c69f0089d11f9930c2ace1", null ],
    [ "G_GCLIB_UTILITY_ERROR_S", "group__cpp__api.html#ga8dde41f95622092e369da423ad2e44dd", null ],
    [ "G_GCLIB_UTILITY_IP_TAKEN", "group__cpp__api.html#gaecd7f62e0972ac4be677ba68365d11e5", null ],
    [ "G_GCLIB_UTILITY_IP_TAKEN_S", "group__cpp__api.html#ga31b428919468e475ba05836d00de1faf", null ],
    [ "G_ILLEGAL_DATA_IN_PROGRAM", "group__cpp__api.html#gafc7d5bb6ad219829ca6533ff87d96056", null ],
    [ "G_ILLEGAL_DATA_IN_PROGRAM_S", "group__cpp__api.html#gaf7e6b95de220f39f61f8a35abf303fa6", null ],
    [ "G_INVALID_PREPROCESSOR_OPTIONS", "group__cpp__api.html#ga4bcc4cc8c4880acf82319cbdec827d47", null ],
    [ "G_INVALID_PREPROCESSOR_OPTIONS_S", "group__cpp__api.html#ga7ee237937c4335a6b43ed94319115035", null ],
    [ "G_NO_ERROR", "group__cpp__api.html#ga46e5adb966864971f3d6b4a1decf5954", null ],
    [ "G_NO_ERROR_S", "group__cpp__api.html#ga7d6dd86ae2b6307adf6d05f108269cf8", null ],
    [ "G_OPEN_ERROR", "group__cpp__api.html#ga44e34d4559d3d09cd550c45e12483108", null ],
    [ "G_OPEN_ERROR_S", "group__cpp__api.html#gacc70913c5d86130391fab2a2ba5155bb", null ],
    [ "G_READ_ERROR", "group__cpp__api.html#gabce68d1f465996cbaaac153b9940d621", null ],
    [ "G_READ_ERROR_S", "group__cpp__api.html#ga20a339f9fa688b67c47706a3b057b9d3", null ],
    [ "G_TIMEOUT", "group__cpp__api.html#gaef68529afafeb30e5f60c9d698408bf0", null ],
    [ "G_TIMEOUT_S", "group__cpp__api.html#ga9651f9c31449c92cc0edd295136d4ebd", null ],
    [ "G_UNABLE_TO_COMPRESS_PROGRAM_TO_FIT", "group__cpp__api.html#gae1864af8c72153a6f00432fac75dc5b4", null ],
    [ "G_UNABLE_TO_COMPRESS_PROGRAM_TO_FIT_S", "group__cpp__api.html#ga0349cd85016a55aefcf1281c49e6b119", null ],
    [ "G_UNSUPPORTED_FUNCTION", "group__cpp__api.html#gab6ff4f5067dbe90c1e369ecf878848fd", null ],
    [ "G_UNSUPPORTED_FUNCTION_S", "group__cpp__api.html#ga89cf3cf24b91c0eb79a794a2445a327c", null ],
    [ "G_WRITE_ERROR", "group__cpp__api.html#ga036c9dd80229ef8a3343281e5d64e026", null ],
    [ "G_WRITE_ERROR_S", "group__cpp__api.html#gaf35a97da9caf2b7965f9c1eb7fc370b5", null ]
];
